/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.transform.colmerge;

import lombok.Getter;
import lombok.Setter;
import org.apache.seatunnel.api.configuration.Option;
import org.apache.seatunnel.api.configuration.Options;
import org.apache.seatunnel.api.configuration.ReadonlyConfig;
import org.apache.seatunnel.transform.condition.ConditionEntity;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

@Getter
@Setter
public class ColMergeTransformConfig implements Serializable {

    public static final Option<String> KEY_SEPARATOR =
            Options.key("separator")
                    .stringType()
                    .noDefaultValue()
                    .withDescription("Specify the separator");

    public static final Option<Boolean> KEY_IS_RETAIN =
            Options.key("is_retain")
                    .booleanType()
                    .noDefaultValue()
                    .withDescription("Specify the fields is retain or not");

    public static final Option<String> KEY_DEST_FIELD =
            Options.key("dest_field")
                    .stringType()
                    .noDefaultValue()
                    .withDescription("Copy Src field to Dest field");


    public static final Option<List<String>> KEY_KEY_FIELDS =
            Options.key("fields")
                    .listType()
                    .noDefaultValue()
                    .withDescription(
                            "The list of fields that need to be merge.");

    //分隔符
    private String separator;

    //是否保留原有字段
    private boolean isRetain;

    //合并后的字段
    private String destField;

    //合并的字段集合
    private List<String> fields;

    public static ColMergeTransformConfig of(ReadonlyConfig config) {
        ColMergeTransformConfig conditionTransformConfig = new ColMergeTransformConfig();
        conditionTransformConfig.setSeparator(config.get(KEY_SEPARATOR));
        conditionTransformConfig.setRetain(config.get(KEY_IS_RETAIN));
        conditionTransformConfig.setDestField(config.get(KEY_DEST_FIELD));
        conditionTransformConfig.setFields(config.get(KEY_KEY_FIELDS));
        return conditionTransformConfig;
    }
}
