/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.transform.colmerge;

import com.google.auto.service.AutoService;
import lombok.NonNull;
import org.apache.seatunnel.api.configuration.util.OptionRule;
import org.apache.seatunnel.api.table.catalog.CatalogTable;
import org.apache.seatunnel.api.table.connector.TableTransform;
import org.apache.seatunnel.api.table.factory.Factory;
import org.apache.seatunnel.api.table.factory.TableFactoryContext;
import org.apache.seatunnel.api.table.factory.TableTransformFactory;

@AutoService(Factory.class)
public class ColMergeTransformFactory implements TableTransformFactory {
    @Override
    public String factoryIdentifier() {
        return "ColMerge";
    }

    @Override
    public OptionRule optionRule() {
        return OptionRule.builder()
                .required(
//                        ColMergeTransformConfig.KEY_SEPARATOR.withFallbackKeys(),
                        ColMergeTransformConfig.KEY_IS_RETAIN.withFallbackKeys().withFallbackKeys(),
                        ColMergeTransformConfig.KEY_KEY_FIELDS.withFallbackKeys().withFallbackKeys(),
                        ColMergeTransformConfig.KEY_DEST_FIELD.withFallbackKeys()
                )
                .build();
    }

    @Override
    public TableTransform createTransform(@NonNull TableFactoryContext context) {
        ColMergeTransformConfig colMergeTransformConfig = ColMergeTransformConfig.of(context.getOptions());
        CatalogTable catalogTable = context.getCatalogTable();
        return () -> new ColMergeTransform(colMergeTransformConfig, catalogTable);
    }
}
