/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.transform.primaryadd;

import lombok.Getter;
import lombok.Setter;
import org.apache.seatunnel.api.configuration.Option;
import org.apache.seatunnel.api.configuration.Options;
import org.apache.seatunnel.api.configuration.ReadonlyConfig;

import java.io.Serializable;
import java.util.List;

@Getter
@Setter
public class PrimaryAddTransformConfig implements Serializable {

    public static final Option<String> KEY_PRIMARY =
            Options.key("primary")
                    .stringType()
                    .noDefaultValue()
                    .withDescription("Specify the primary");

    public static final Option<String> KEY_GEN_METHOD =
            Options.key("genMethod")
                    .stringType()
                    .defaultValue("SnowFlake")
                    .withDescription("Specify the genMethod");

    //主键名称
    private String primary;

    //生成主键方式,目前支持UUID和SnowFlake
    private String genMethod;

    public static PrimaryAddTransformConfig of(ReadonlyConfig config) {
        PrimaryAddTransformConfig primaryAddTransformConfig = new PrimaryAddTransformConfig();
        primaryAddTransformConfig.setPrimary(config.get(KEY_PRIMARY));
        primaryAddTransformConfig.setGenMethod(config.get(KEY_GEN_METHOD));
        return primaryAddTransformConfig;
    }
}
