/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.transform.rowstack;

import lombok.Getter;
import lombok.Setter;
import org.apache.seatunnel.api.configuration.Option;
import org.apache.seatunnel.api.configuration.Options;
import org.apache.seatunnel.api.configuration.ReadonlyConfig;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

@Getter
@Setter
public class RowStackTransformConfig implements Serializable {

//
//    public static final Option<String> KEY_MAIN_TABLE =
//            Options.key("main_table")
//                    .stringType()
//                    .noDefaultValue()
//                    .withDescription("Specify the main_table");


    public static final Option<List<String>> KEY_FIELDS =
            Options.key("fields")
                    .listType(String.class)
                    .noDefaultValue()
                    .withDescription("Specify the fields");

    public static final Option<List<String>> KEY_FIELD_TYPES =
            Options.key("field_types")
                    .listType(String.class)
                    .noDefaultValue()
                    .withDescription("Specify the fields_type");



    public static final Option<List<RowStackEntity>> KEY_FIELD_CONFIG =
            Options.key("field_config")
                    .listType(RowStackEntity.class)
                    .noDefaultValue()
                    .withDescription(
                            "Specify the field_config");


//    private String mainTable;

    private List<String> fieldList = new ArrayList<>();

    private List<String> fieldTypeList = new ArrayList<>();

    private List<RowStackEntity> fieldConfigList = new ArrayList<>();


    public static RowStackTransformConfig of(ReadonlyConfig config) {
        RowStackTransformConfig rowStackTransformConfig = new RowStackTransformConfig();
//        rowStackTransformConfig.setMainTable(config.get(KEY_MAIN_TABLE));
        rowStackTransformConfig.setFieldList(config.get(KEY_FIELDS));
        rowStackTransformConfig.setFieldTypeList(config.get(KEY_FIELD_TYPES));
        rowStackTransformConfig.setFieldConfigList(config.get(KEY_FIELD_CONFIG));
        return rowStackTransformConfig;
    }
}
